pub struct Guard { /* private fields */ }Expand description
An epoch guard that keeps the current thread pinned.
While a guard exists, any memory retired during this epoch will not be reclaimed. Guards should be short-lived to avoid delaying reclamation.
Obtain a guard via LearnedMap::guard or use LearnedMap::pin for
the convenience MapRef wrapper.